# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/group.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'olvid/daemon/datatypes/v1/group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%olvid/daemon/datatypes/v1/group.proto\x12\x19olvid.daemon.datatypes.v1\"\x93\x08\n\x05Group\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x39\n\x04type\x18\x02 \x01(\x0e\x32%.olvid.daemon.datatypes.v1.Group.TypeR\x04type\x12r\n\x16\x61\x64vanced_configuration\x18\x03 \x01(\x0b\x32\x36.olvid.daemon.datatypes.v1.Group.AdvancedConfigurationH\x00R\x15\x61\x64vancedConfiguration\x88\x01\x01\x12Z\n\x0fown_permissions\x18\x04 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x0eownPermissions\x12@\n\x07members\x18\x05 \x03(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x07members\x12V\n\x0fpending_members\x18\x06 \x03(\x0b\x32-.olvid.daemon.datatypes.v1.PendingGroupMemberR\x0ependingMembers\x12,\n\x12update_in_progress\x18\x07 \x01(\x08R\x10updateInProgress\x12)\n\x10keycloak_managed\x18\x08 \x01(\x08R\x0fkeycloakManaged\x12\x12\n\x04name\x18\t \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\n \x01(\tR\x0b\x64\x65scription\x12\x1e\n\x0bhas_a_photo\x18\x0b \x01(\x08R\thasAPhoto\x1a\x9d\x02\n\x15\x41\x64vancedConfiguration\x12\x1b\n\tread_only\x18\x01 \x01(\x08R\x08readOnly\x12h\n\rremote_delete\x18\x02 \x01(\x0e\x32\x43.olvid.daemon.datatypes.v1.Group.AdvancedConfiguration.RemoteDeleteR\x0cremoteDelete\"}\n\x0cRemoteDelete\x12\x1d\n\x19REMOTE_DELETE_UNSPECIFIED\x10\x00\x12\x18\n\x14REMOTE_DELETE_NOBODY\x10\x01\x12\x18\n\x14REMOTE_DELETE_ADMINS\x10\x02\x12\x1a\n\x16REMOTE_DELETE_EVERYONE\x10\x03\"k\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rTYPE_STANDARD\x10\x01\x12\x13\n\x0fTYPE_CONTROLLED\x10\x02\x12\x12\n\x0eTYPE_READ_ONLY\x10\x03\x12\x11\n\rTYPE_ADVANCED\x10\x04\x42\x19\n\x17_advanced_configuration\"\x81\x01\n\x0bGroupMember\x12\x1d\n\ncontact_id\x18\x01 \x01(\x04R\tcontactId\x12S\n\x0bpermissions\x18\x02 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x0bpermissions\"\xf3\x01\n\x12PendingGroupMember\x12*\n\x11pending_member_id\x18\x01 \x01(\x04R\x0fpendingMemberId\x12\x1d\n\ncontact_id\x18\x02 \x01(\x04R\tcontactId\x12!\n\x0c\x64isplay_name\x18\x03 \x01(\tR\x0b\x64isplayName\x12\x1a\n\x08\x64\x65\x63lined\x18\x04 \x01(\x08R\x08\x64\x65\x63lined\x12S\n\x0bpermissions\x18\x05 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x0bpermissions\"\xfb\x01\n\x16GroupMemberPermissions\x12\x14\n\x05\x61\x64min\x18\x01 \x01(\x08R\x05\x61\x64min\x12\x34\n\x16remote_delete_anything\x18\x02 \x01(\x08R\x14remoteDeleteAnything\x12I\n\"edit_or_remote_delete_own_messages\x18\x03 \x01(\x08R\x1d\x65\x64itOrRemoteDeleteOwnMessages\x12\'\n\x0f\x63hange_settings\x18\x04 \x01(\x08R\x0e\x63hangeSettings\x12!\n\x0csend_message\x18\x05 \x01(\x08R\x0bsendMessage\"\xf2\x07\n\x0bGroupFilter\x12>\n\x04type\x18\x01 \x01(\x0e\x32%.olvid.daemon.datatypes.v1.Group.TypeH\x00R\x04type\x88\x01\x01\x12G\n\x05\x65mpty\x18\x02 \x01(\x0e\x32,.olvid.daemon.datatypes.v1.GroupFilter.EmptyH\x01R\x05\x65mpty\x88\x01\x01\x12G\n\x05photo\x18\x03 \x01(\x0e\x32,.olvid.daemon.datatypes.v1.GroupFilter.PhotoH\x02R\x05photo\x88\x01\x01\x12P\n\x08keycloak\x18\x04 \x01(\x0e\x32/.olvid.daemon.datatypes.v1.GroupFilter.KeycloakH\x03R\x08keycloak\x88\x01\x01\x12k\n\x16own_permissions_filter\x18\x05 \x01(\x0b\x32\x30.olvid.daemon.datatypes.v1.GroupPermissionFilterH\x04R\x14ownPermissionsFilter\x88\x01\x01\x12$\n\x0bname_search\x18\x06 \x01(\tH\x05R\nnameSearch\x88\x01\x01\x12\x32\n\x12\x64\x65scription_search\x18\x07 \x01(\tH\x06R\x11\x64\x65scriptionSearch\x88\x01\x01\x12S\n\x0emember_filters\x18\x08 \x03(\x0b\x32,.olvid.daemon.datatypes.v1.GroupMemberFilterR\rmemberFilters\x12i\n\x16pending_member_filters\x18\t \x03(\x0b\x32\x33.olvid.daemon.datatypes.v1.PendingGroupMemberFilterR\x14pendingMemberFilters\">\n\x05\x45mpty\x12\x15\n\x11\x45MPTY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x45MPTY_IS\x10\x02\x12\x10\n\x0c\x45MPTY_IS_NOT\x10\x01\"J\n\x08Keycloak\x12\x18\n\x14KEYCLOAK_UNSPECIFIED\x10\x00\x12\x0f\n\x0bKEYCLOAK_IS\x10\x02\x12\x13\n\x0fKEYCLOAK_IS_NOT\x10\x01\"@\n\x05Photo\x12\x15\n\x11PHOTO_UNSPECIFIED\x10\x00\x12\r\n\tPHOTO_HAS\x10\x02\x12\x11\n\rPHOTO_HAS_NOT\x10\x01\x42\x07\n\x05_typeB\x08\n\x06_emptyB\x08\n\x06_photoB\x0b\n\t_keycloakB\x19\n\x17_own_permissions_filterB\x0e\n\x0c_name_searchB\x15\n\x13_description_search\"\xaf\x01\n\x11GroupMemberFilter\x12\"\n\ncontact_id\x18\x01 \x01(\x04H\x00R\tcontactId\x88\x01\x01\x12W\n\x0bpermissions\x18\x05 \x01(\x0b\x32\x30.olvid.daemon.datatypes.v1.GroupPermissionFilterH\x01R\x0bpermissions\x88\x01\x01\x42\r\n\x0b_contact_idB\x0e\n\x0c_permissions\"\x80\x05\n\x18PendingGroupMemberFilter\x12_\n\nis_contact\x18\x01 \x01(\x0e\x32;.olvid.daemon.datatypes.v1.PendingGroupMemberFilter.ContactH\x00R\tisContact\x88\x01\x01\x12\x64\n\x0chas_declined\x18\x02 \x01(\x0e\x32<.olvid.daemon.datatypes.v1.PendingGroupMemberFilter.DeclinedH\x01R\x0bhasDeclined\x88\x01\x01\x12\"\n\ncontact_id\x18\x03 \x01(\x04H\x02R\tcontactId\x88\x01\x01\x12\x33\n\x13\x64isplay_name_search\x18\x04 \x01(\tH\x03R\x11\x64isplayNameSearch\x88\x01\x01\x12W\n\x0bpermissions\x18\x05 \x01(\x0b\x32\x30.olvid.daemon.datatypes.v1.GroupPermissionFilterH\x04R\x0bpermissions\x88\x01\x01\"F\n\x07\x43ontact\x12\x17\n\x13\x43ONTACT_UNSPECIFIED\x10\x00\x12\x0e\n\nCONTACT_IS\x10\x01\x12\x12\n\x0e\x43ONTACT_IS_NOT\x10\x02\"L\n\x08\x44\x65\x63lined\x12\x18\n\x14\x44\x45\x43LINED_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x44\x45\x43LINED_HAS\x10\x01\x12\x14\n\x10\x44\x45\x43LINED_HAS_NOT\x10\x02\x42\r\n\x0b_is_contactB\x0f\n\r_has_declinedB\r\n\x0b_contact_idB\x16\n\x14_display_name_searchB\x0e\n\x0c_permissions\"\x88\n\n\x15GroupPermissionFilter\x12Q\n\x05\x61\x64min\x18\x01 \x01(\x0e\x32\x36.olvid.daemon.datatypes.v1.GroupPermissionFilter.AdminH\x00R\x05\x61\x64min\x88\x01\x01\x12\x64\n\x0csend_message\x18\x02 \x01(\x0e\x32<.olvid.daemon.datatypes.v1.GroupPermissionFilter.SendMessageH\x01R\x0bsendMessage\x88\x01\x01\x12\x80\x01\n\x16remote_delete_anything\x18\x03 \x01(\x0e\x32\x45.olvid.daemon.datatypes.v1.GroupPermissionFilter.RemoteDeleteAnythingH\x02R\x14remoteDeleteAnything\x88\x01\x01\x12\x9d\x01\n\"edit_or_remote_delete_own_messages\x18\x04 \x01(\x0e\x32M.olvid.daemon.datatypes.v1.GroupPermissionFilter.EditOrRemoteDeleteOwnMessageH\x03R\x1d\x65\x64itOrRemoteDeleteOwnMessages\x88\x01\x01\x12m\n\x0f\x63hange_settings\x18\x05 \x01(\x0e\x32?.olvid.daemon.datatypes.v1.GroupPermissionFilter.ChangeSettingsH\x04R\x0e\x63hangeSettings\x88\x01\x01\">\n\x05\x41\x64min\x12\x15\n\x11\x41\x44MIN_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x41\x44MIN_IS\x10\x01\x12\x10\n\x0c\x41\x44MIN_IS_NOT\x10\x02\"Z\n\x0bSendMessage\x12\x1c\n\x18SEND_MESSAGE_UNSPECIFIED\x10\x00\x12\x14\n\x10SEND_MESSAGE_CAN\x10\x01\x12\x17\n\x13SEND_MESSAGE_CANNOT\x10\x02\"\x81\x01\n\x14RemoteDeleteAnything\x12&\n\"REMOTE_DELETE_ANYTHING_UNSPECIFIED\x10\x00\x12\x1e\n\x1aREMOTE_DELETE_ANYTHING_CAN\x10\x01\x12!\n\x1dREMOTE_DELETE_ANYTHING_CANNOT\x10\x02\"\xaa\x01\n\x1c\x45\x64itOrRemoteDeleteOwnMessage\x12\x31\n-EDIT_OR_REMOTE_DELETE_OWN_MESSAGE_UNSPECIFIED\x10\x00\x12)\n%EDIT_OR_REMOTE_DELETE_OWN_MESSAGE_CAN\x10\x01\x12,\n(EDIT_OR_REMOTE_DELETE_OWN_MESSAGE_CANNOT\x10\x02\"f\n\x0e\x43hangeSettings\x12\x1f\n\x1b\x43HANGE_SETTINGS_UNSPECIFIED\x10\x00\x12\x17\n\x13\x43HANGE_SETTINGS_CAN\x10\x01\x12\x1a\n\x16\x43HANGE_SETTINGS_CANNOT\x10\x02\x42\x08\n\x06_adminB\x0f\n\r_send_messageB\x19\n\x17_remote_delete_anythingB%\n#_edit_or_remote_delete_own_messagesB\x12\n\x10_change_settingsB\xc3\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\nGroupProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\nGroupProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_GROUP']._serialized_start=69
  _globals['_GROUP']._serialized_end=1112
  _globals['_GROUP_ADVANCEDCONFIGURATION']._serialized_start=691
  _globals['_GROUP_ADVANCEDCONFIGURATION']._serialized_end=976
  _globals['_GROUP_ADVANCEDCONFIGURATION_REMOTEDELETE']._serialized_start=851
  _globals['_GROUP_ADVANCEDCONFIGURATION_REMOTEDELETE']._serialized_end=976
  _globals['_GROUP_TYPE']._serialized_start=978
  _globals['_GROUP_TYPE']._serialized_end=1085
  _globals['_GROUPMEMBER']._serialized_start=1115
  _globals['_GROUPMEMBER']._serialized_end=1244
  _globals['_PENDINGGROUPMEMBER']._serialized_start=1247
  _globals['_PENDINGGROUPMEMBER']._serialized_end=1490
  _globals['_GROUPMEMBERPERMISSIONS']._serialized_start=1493
  _globals['_GROUPMEMBERPERMISSIONS']._serialized_end=1744
  _globals['_GROUPFILTER']._serialized_start=1747
  _globals['_GROUPFILTER']._serialized_end=2757
  _globals['_GROUPFILTER_EMPTY']._serialized_start=2445
  _globals['_GROUPFILTER_EMPTY']._serialized_end=2507
  _globals['_GROUPFILTER_KEYCLOAK']._serialized_start=2509
  _globals['_GROUPFILTER_KEYCLOAK']._serialized_end=2583
  _globals['_GROUPFILTER_PHOTO']._serialized_start=2585
  _globals['_GROUPFILTER_PHOTO']._serialized_end=2649
  _globals['_GROUPMEMBERFILTER']._serialized_start=2760
  _globals['_GROUPMEMBERFILTER']._serialized_end=2935
  _globals['_PENDINGGROUPMEMBERFILTER']._serialized_start=2938
  _globals['_PENDINGGROUPMEMBERFILTER']._serialized_end=3578
  _globals['_PENDINGGROUPMEMBERFILTER_CONTACT']._serialized_start=3343
  _globals['_PENDINGGROUPMEMBERFILTER_CONTACT']._serialized_end=3413
  _globals['_PENDINGGROUPMEMBERFILTER_DECLINED']._serialized_start=3415
  _globals['_PENDINGGROUPMEMBERFILTER_DECLINED']._serialized_end=3491
  _globals['_GROUPPERMISSIONFILTER']._serialized_start=3581
  _globals['_GROUPPERMISSIONFILTER']._serialized_end=4869
  _globals['_GROUPPERMISSIONFILTER_ADMIN']._serialized_start=4193
  _globals['_GROUPPERMISSIONFILTER_ADMIN']._serialized_end=4255
  _globals['_GROUPPERMISSIONFILTER_SENDMESSAGE']._serialized_start=4257
  _globals['_GROUPPERMISSIONFILTER_SENDMESSAGE']._serialized_end=4347
  _globals['_GROUPPERMISSIONFILTER_REMOTEDELETEANYTHING']._serialized_start=4350
  _globals['_GROUPPERMISSIONFILTER_REMOTEDELETEANYTHING']._serialized_end=4479
  _globals['_GROUPPERMISSIONFILTER_EDITORREMOTEDELETEOWNMESSAGE']._serialized_start=4482
  _globals['_GROUPPERMISSIONFILTER_EDITORREMOTEDELETEOWNMESSAGE']._serialized_end=4652
  _globals['_GROUPPERMISSIONFILTER_CHANGESETTINGS']._serialized_start=4654
  _globals['_GROUPPERMISSIONFILTER_CHANGESETTINGS']._serialized_end=4756
# @@protoc_insertion_point(module_scope)
