# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/invitation_notifications.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'olvid/daemon/notification/v1/invitation_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import invitation_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_invitation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;olvid/daemon/notification/v1/invitation_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a*olvid/daemon/datatypes/v1/invitation.proto\"+\n)SubscribeToInvitationReceivedNotification\"g\n\x1eInvitationReceivedNotification\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\"\'\n%SubscribeToInvitationSentNotification\"c\n\x1aInvitationSentNotification\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\"*\n(SubscribeToInvitationDeletedNotification\"f\n\x1dInvitationDeletedNotification\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\"*\n(SubscribeToInvitationUpdatedNotification\"\xd2\x01\n\x1dInvitationUpdatedNotification\x12\x45\n\ninvitation\x18\x01 \x01(\x0b\x32%.olvid.daemon.datatypes.v1.InvitationR\ninvitation\x12j\n\x1aprevious_invitation_status\x18\x02 \x01(\x0e\x32,.olvid.daemon.datatypes.v1.Invitation.StatusR\x18previousInvitationStatusB\xe4\x01\n com.olvid.daemon.notification.v1B\x1cInvitationNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.invitation_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\034InvitationNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOINVITATIONRECEIVEDNOTIFICATION']._serialized_start=137
  _globals['_SUBSCRIBETOINVITATIONRECEIVEDNOTIFICATION']._serialized_end=180
  _globals['_INVITATIONRECEIVEDNOTIFICATION']._serialized_start=182
  _globals['_INVITATIONRECEIVEDNOTIFICATION']._serialized_end=285
  _globals['_SUBSCRIBETOINVITATIONSENTNOTIFICATION']._serialized_start=287
  _globals['_SUBSCRIBETOINVITATIONSENTNOTIFICATION']._serialized_end=326
  _globals['_INVITATIONSENTNOTIFICATION']._serialized_start=328
  _globals['_INVITATIONSENTNOTIFICATION']._serialized_end=427
  _globals['_SUBSCRIBETOINVITATIONDELETEDNOTIFICATION']._serialized_start=429
  _globals['_SUBSCRIBETOINVITATIONDELETEDNOTIFICATION']._serialized_end=471
  _globals['_INVITATIONDELETEDNOTIFICATION']._serialized_start=473
  _globals['_INVITATIONDELETEDNOTIFICATION']._serialized_end=575
  _globals['_SUBSCRIBETOINVITATIONUPDATEDNOTIFICATION']._serialized_start=577
  _globals['_SUBSCRIBETOINVITATIONUPDATEDNOTIFICATION']._serialized_end=619
  _globals['_INVITATIONUPDATEDNOTIFICATION']._serialized_start=622
  _globals['_INVITATIONUPDATEDNOTIFICATION']._serialized_end=832
# @@protoc_insertion_point(module_scope)
