# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/invitation.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'olvid/daemon/datatypes/v1/invitation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*olvid/daemon/datatypes/v1/invitation.proto\x12\x19olvid.daemon.datatypes.v1\"\xca\x05\n\nInvitation\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x44\n\x06status\x18\x02 \x01(\x0e\x32,.olvid.daemon.datatypes.v1.Invitation.StatusR\x06status\x12!\n\x0c\x64isplay_name\x18\x03 \x01(\tR\x0b\x64isplayName\x12\x1c\n\ttimestamp\x18\x04 \x01(\x04R\ttimestamp\x12\x10\n\x03sas\x18\x05 \x01(\tR\x03sas\"\x92\x04\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12(\n$STATUS_INVITATION_WAIT_YOU_TO_ACCEPT\x10\x01\x12\'\n#STATUS_INVITATION_WAIT_IT_TO_ACCEPT\x10\x02\x12(\n$STATUS_INVITATION_STATUS_IN_PROGRESS\x10\x03\x12/\n+STATUS_INVITATION_WAIT_YOU_FOR_SAS_EXCHANGE\x10\x04\x12.\n*STATUS_INVITATION_WAIT_IT_FOR_SAS_EXCHANGE\x10\x05\x12)\n%STATUS_INTRODUCTION_WAIT_IT_TO_ACCEPT\x10\x07\x12*\n&STATUS_INTRODUCTION_WAIT_YOU_TO_ACCEPT\x10\x08\x12\x32\n.STATUS_ONE_TO_ONE_INVITATION_WAIT_IT_TO_ACCEPT\x10\t\x12\x33\n/STATUS_ONE_TO_ONE_INVITATION_WAIT_YOU_TO_ACCEPT\x10\n\x12.\n*STATUS_GROUP_INVITATION_WAIT_YOU_TO_ACCEPT\x10\x0b\x12\"\n\x1eSTATUS_GROUP_INVITATION_FROZEN\x10\x0c\"\xf0\x03\n\x10InvitationFilter\x12I\n\x06status\x18\x01 \x01(\x0e\x32,.olvid.daemon.datatypes.v1.Invitation.StatusH\x00R\x06status\x88\x01\x01\x12I\n\x04type\x18\x02 \x01(\x0e\x32\x30.olvid.daemon.datatypes.v1.InvitationFilter.TypeH\x01R\x04type\x88\x01\x01\x12\x33\n\x13\x64isplay_name_search\x18\x03 \x01(\tH\x02R\x11\x64isplayNameSearch\x88\x01\x01\x12(\n\rmin_timestamp\x18\x04 \x01(\x04H\x03R\x0cminTimestamp\x88\x01\x01\x12(\n\rmax_timestamp\x18\x05 \x01(\x04H\x04R\x0cmaxTimestamp\x88\x01\x01\"m\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fTYPE_INVITATION\x10\x01\x12\x15\n\x11TYPE_INTRODUCTION\x10\x02\x12\x0e\n\nTYPE_GROUP\x10\x03\x12\x13\n\x0fTYPE_ONE_TO_ONE\x10\x04\x42\t\n\x07_statusB\x07\n\x05_typeB\x16\n\x14_display_name_searchB\x10\n\x0e_min_timestampB\x10\n\x0e_max_timestampB\xc8\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\x0fInvitationProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.invitation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\017InvitationProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_INVITATION']._serialized_start=74
  _globals['_INVITATION']._serialized_end=788
  _globals['_INVITATION_STATUS']._serialized_start=258
  _globals['_INVITATION_STATUS']._serialized_end=788
  _globals['_INVITATIONFILTER']._serialized_start=791
  _globals['_INVITATIONFILTER']._serialized_end=1287
  _globals['_INVITATIONFILTER_TYPE']._serialized_start=1098
  _globals['_INVITATIONFILTER_TYPE']._serialized_end=1207
# @@protoc_insertion_point(module_scope)
