# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/identity_commands.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'olvid/daemon/command/v1/identity_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import identity_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/olvid/daemon/command/v1/identity_commands.proto\x12\x17olvid.daemon.command.v1\x1a(olvid/daemon/datatypes/v1/identity.proto\"\x14\n\x12IdentityGetRequest\"V\n\x13IdentityGetResponse\x12?\n\x08identity\x18\x01 \x01(\x0b\x32#.olvid.daemon.datatypes.v1.IdentityR\x08identity\"k\n\x1cIdentityUpdateDetailsRequest\x12K\n\x0bnew_details\x18\x02 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.IdentityDetailsR\nnewDetails\"\x1f\n\x1dIdentityUpdateDetailsResponse\"\x1c\n\x1aIdentityRemovePhotoRequest\"\x1d\n\x1bIdentityRemovePhotoResponse\"Z\n\x1fIdentitySetPhotoRequestMetadata\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12\x1b\n\tfile_size\x18\x02 \x01(\x04R\x08\x66ileSize\"\x98\x01\n\x17IdentitySetPhotoRequest\x12V\n\x08metadata\x18\x01 \x01(\x0b\x32\x38.olvid.daemon.command.v1.IdentitySetPhotoRequestMetadataH\x00R\x08metadata\x12\x1a\n\x07payload\x18\x02 \x01(\x0cH\x00R\x07payloadB\t\n\x07request\"\x1a\n\x18IdentitySetPhotoResponse\"L\n\x1bIdentityKeycloakBindRequest\x12-\n\x12\x63onfiguration_link\x18\x01 \x01(\tR\x11\x63onfigurationLink\"\x1e\n\x1cIdentityKeycloakBindResponse\"\x1f\n\x1dIdentityKeycloakUnbindRequest\" \n\x1eIdentityKeycloakUnbindResponse\"3\n\x18IdentitySetApiKeyRequest\x12\x17\n\x07\x61pi_key\x18\x01 \x01(\tR\x06\x61piKey\"`\n\x19IdentitySetApiKeyResponse\x12\x43\n\x07\x61pi_key\x18\x01 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.Identity.ApiKeyR\x06\x61piKey\"T\n#IdentitySetConfigurationLinkRequest\x12-\n\x12\x63onfiguration_link\x18\x01 \x01(\tR\x11\x63onfigurationLink\"k\n$IdentitySetConfigurationLinkResponse\x12\x43\n\x07\x61pi_key\x18\x01 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.Identity.ApiKeyR\x06\x61piKeyB\xc4\x01\n\x1b\x63om.olvid.daemon.command.v1B\x15IdentityCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.identity_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\025IdentityCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_IDENTITYGETREQUEST']._serialized_start=118
  _globals['_IDENTITYGETREQUEST']._serialized_end=138
  _globals['_IDENTITYGETRESPONSE']._serialized_start=140
  _globals['_IDENTITYGETRESPONSE']._serialized_end=226
  _globals['_IDENTITYUPDATEDETAILSREQUEST']._serialized_start=228
  _globals['_IDENTITYUPDATEDETAILSREQUEST']._serialized_end=335
  _globals['_IDENTITYUPDATEDETAILSRESPONSE']._serialized_start=337
  _globals['_IDENTITYUPDATEDETAILSRESPONSE']._serialized_end=368
  _globals['_IDENTITYREMOVEPHOTOREQUEST']._serialized_start=370
  _globals['_IDENTITYREMOVEPHOTOREQUEST']._serialized_end=398
  _globals['_IDENTITYREMOVEPHOTORESPONSE']._serialized_start=400
  _globals['_IDENTITYREMOVEPHOTORESPONSE']._serialized_end=429
  _globals['_IDENTITYSETPHOTOREQUESTMETADATA']._serialized_start=431
  _globals['_IDENTITYSETPHOTOREQUESTMETADATA']._serialized_end=521
  _globals['_IDENTITYSETPHOTOREQUEST']._serialized_start=524
  _globals['_IDENTITYSETPHOTOREQUEST']._serialized_end=676
  _globals['_IDENTITYSETPHOTORESPONSE']._serialized_start=678
  _globals['_IDENTITYSETPHOTORESPONSE']._serialized_end=704
  _globals['_IDENTITYKEYCLOAKBINDREQUEST']._serialized_start=706
  _globals['_IDENTITYKEYCLOAKBINDREQUEST']._serialized_end=782
  _globals['_IDENTITYKEYCLOAKBINDRESPONSE']._serialized_start=784
  _globals['_IDENTITYKEYCLOAKBINDRESPONSE']._serialized_end=814
  _globals['_IDENTITYKEYCLOAKUNBINDREQUEST']._serialized_start=816
  _globals['_IDENTITYKEYCLOAKUNBINDREQUEST']._serialized_end=847
  _globals['_IDENTITYKEYCLOAKUNBINDRESPONSE']._serialized_start=849
  _globals['_IDENTITYKEYCLOAKUNBINDRESPONSE']._serialized_end=881
  _globals['_IDENTITYSETAPIKEYREQUEST']._serialized_start=883
  _globals['_IDENTITYSETAPIKEYREQUEST']._serialized_end=934
  _globals['_IDENTITYSETAPIKEYRESPONSE']._serialized_start=936
  _globals['_IDENTITYSETAPIKEYRESPONSE']._serialized_end=1032
  _globals['_IDENTITYSETCONFIGURATIONLINKREQUEST']._serialized_start=1034
  _globals['_IDENTITYSETCONFIGURATIONLINKREQUEST']._serialized_end=1118
  _globals['_IDENTITYSETCONFIGURATIONLINKRESPONSE']._serialized_start=1120
  _globals['_IDENTITYSETCONFIGURATIONLINKRESPONSE']._serialized_end=1227
# @@protoc_insertion_point(module_scope)
