# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/message_commands.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'olvid/daemon/command/v1/message_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import attachment_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_attachment__pb2
from .....olvid.daemon.datatypes.v1 import message_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.olvid/daemon/command/v1/message_commands.proto\x12\x17olvid.daemon.command.v1\x1a*olvid/daemon/datatypes/v1/attachment.proto\x1a\'olvid/daemon/datatypes/v1/message.proto\"\x8e\x01\n\x12MessageListRequest\x12\x45\n\x06\x66ilter\x18\x01 \x01(\x0b\x32(.olvid.daemon.datatypes.v1.MessageFilterH\x00R\x06\x66ilter\x88\x01\x01\x12\x1b\n\x06unread\x18\x02 \x01(\x08H\x01R\x06unread\x88\x01\x01\x42\t\n\x07_filterB\t\n\x07_unread\"U\n\x13MessageListResponse\x12>\n\x08messages\x18\x01 \x03(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x08messages\"X\n\x11MessageGetRequest\x12\x43\n\nmessage_id\x18\x01 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\tmessageId\"R\n\x12MessageGetResponse\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\x17\n\x15MessageRefreshRequest\"\x18\n\x16MessageRefreshResponse\"\xa3\x01\n\x14MessageDeleteRequest\x12\x43\n\nmessage_id\x18\x01 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\tmessageId\x12\x30\n\x11\x64\x65lete_everywhere\x18\x02 \x01(\x08H\x00R\x10\x64\x65leteEverywhere\x88\x01\x01\x42\x14\n\x12_delete_everywhere\"\x17\n\x15MessageDeleteResponse\"\xda\x02\n\x12MessageSendRequest\x12#\n\rdiscussion_id\x18\x01 \x01(\x04R\x0c\x64iscussionId\x12\x12\n\x04\x62ody\x18\x02 \x01(\tR\x04\x62ody\x12\x44\n\x08reply_id\x18\x03 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdH\x00R\x07replyId\x88\x01\x01\x12W\n\x0c\x65phemerality\x18\x04 \x01(\x0b\x32..olvid.daemon.datatypes.v1.MessageEphemeralityH\x01R\x0c\x65phemerality\x88\x01\x01\x12\x35\n\x14\x64isable_link_preview\x18\x05 \x01(\x08H\x02R\x12\x64isableLinkPreview\x88\x01\x01\x42\x0b\n\t_reply_idB\x0f\n\r_ephemeralityB\x17\n\x15_disable_link_preview\"S\n\x13MessageSendResponse\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\"\xd5\x01\n!MessageSendWithAttachmentsRequest\x12`\n\x08metadata\x18\x01 \x01(\x0b\x32\x42.olvid.daemon.command.v1.MessageSendWithAttachmentsRequestMetadataH\x00R\x08metadata\x12\x1a\n\x07payload\x18\x02 \x01(\x0cH\x00R\x07payload\x12\'\n\x0e\x66ile_delimiter\x18\x03 \x01(\x08H\x00R\rfileDelimiterB\t\n\x07request\"\x9f\x04\n)MessageSendWithAttachmentsRequestMetadata\x12#\n\rdiscussion_id\x18\x01 \x01(\x04R\x0c\x64iscussionId\x12\x17\n\x04\x62ody\x18\x02 \x01(\tH\x00R\x04\x62ody\x88\x01\x01\x12\x44\n\x08reply_id\x18\x03 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdH\x01R\x07replyId\x88\x01\x01\x12W\n\x0c\x65phemerality\x18\x04 \x01(\x0b\x32..olvid.daemon.datatypes.v1.MessageEphemeralityH\x02R\x0c\x65phemerality\x88\x01\x01\x12\x35\n\x14\x64isable_link_preview\x18\x05 \x01(\x08H\x03R\x12\x64isableLinkPreview\x88\x01\x01\x12]\n\x05\x66iles\x18\n \x03(\x0b\x32G.olvid.daemon.command.v1.MessageSendWithAttachmentsRequestMetadata.FileR\x05\x66iles\x1a?\n\x04\x46ile\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12\x1b\n\tfile_size\x18\x02 \x01(\x04R\x08\x66ileSizeB\x07\n\x05_bodyB\x0b\n\t_reply_idB\x0f\n\r_ephemeralityB\x17\n\x15_disable_link_preview\"\xab\x01\n\"MessageSendWithAttachmentsResponse\x12<\n\x07message\x18\x01 \x01(\x0b\x32\".olvid.daemon.datatypes.v1.MessageR\x07message\x12G\n\x0b\x61ttachments\x18\x02 \x03(\x0b\x32%.olvid.daemon.datatypes.v1.AttachmentR\x0b\x61ttachments\"v\n\x13MessageReactRequest\x12\x43\n\nmessage_id\x18\x01 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\tmessageId\x12\x1a\n\x08reaction\x18\x02 \x01(\tR\x08reaction\"\x16\n\x14MessageReactResponse\"\x82\x01\n\x18MessageUpdateBodyRequest\x12\x43\n\nmessage_id\x18\x01 \x01(\x0b\x32$.olvid.daemon.datatypes.v1.MessageIdR\tmessageId\x12!\n\x0cupdated_body\x18\x02 \x01(\tR\x0bupdatedBody\"\x1b\n\x19MessageUpdateBodyResponse\"=\n\x16MessageSendVoipRequest\x12#\n\rdiscussion_id\x18\x01 \x01(\x04R\x0c\x64iscussionId\"\x19\n\x17MessageSendVoipResponseB\xc3\x01\n\x1b\x63om.olvid.daemon.command.v1B\x14MessageCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.message_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\024MessageCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_MESSAGELISTREQUEST']._serialized_start=161
  _globals['_MESSAGELISTREQUEST']._serialized_end=303
  _globals['_MESSAGELISTRESPONSE']._serialized_start=305
  _globals['_MESSAGELISTRESPONSE']._serialized_end=390
  _globals['_MESSAGEGETREQUEST']._serialized_start=392
  _globals['_MESSAGEGETREQUEST']._serialized_end=480
  _globals['_MESSAGEGETRESPONSE']._serialized_start=482
  _globals['_MESSAGEGETRESPONSE']._serialized_end=564
  _globals['_MESSAGEREFRESHREQUEST']._serialized_start=566
  _globals['_MESSAGEREFRESHREQUEST']._serialized_end=589
  _globals['_MESSAGEREFRESHRESPONSE']._serialized_start=591
  _globals['_MESSAGEREFRESHRESPONSE']._serialized_end=615
  _globals['_MESSAGEDELETEREQUEST']._serialized_start=618
  _globals['_MESSAGEDELETEREQUEST']._serialized_end=781
  _globals['_MESSAGEDELETERESPONSE']._serialized_start=783
  _globals['_MESSAGEDELETERESPONSE']._serialized_end=806
  _globals['_MESSAGESENDREQUEST']._serialized_start=809
  _globals['_MESSAGESENDREQUEST']._serialized_end=1155
  _globals['_MESSAGESENDRESPONSE']._serialized_start=1157
  _globals['_MESSAGESENDRESPONSE']._serialized_end=1240
  _globals['_MESSAGESENDWITHATTACHMENTSREQUEST']._serialized_start=1243
  _globals['_MESSAGESENDWITHATTACHMENTSREQUEST']._serialized_end=1456
  _globals['_MESSAGESENDWITHATTACHMENTSREQUESTMETADATA']._serialized_start=1459
  _globals['_MESSAGESENDWITHATTACHMENTSREQUESTMETADATA']._serialized_end=2002
  _globals['_MESSAGESENDWITHATTACHMENTSREQUESTMETADATA_FILE']._serialized_start=1875
  _globals['_MESSAGESENDWITHATTACHMENTSREQUESTMETADATA_FILE']._serialized_end=1938
  _globals['_MESSAGESENDWITHATTACHMENTSRESPONSE']._serialized_start=2005
  _globals['_MESSAGESENDWITHATTACHMENTSRESPONSE']._serialized_end=2176
  _globals['_MESSAGEREACTREQUEST']._serialized_start=2178
  _globals['_MESSAGEREACTREQUEST']._serialized_end=2296
  _globals['_MESSAGEREACTRESPONSE']._serialized_start=2298
  _globals['_MESSAGEREACTRESPONSE']._serialized_end=2320
  _globals['_MESSAGEUPDATEBODYREQUEST']._serialized_start=2323
  _globals['_MESSAGEUPDATEBODYREQUEST']._serialized_end=2453
  _globals['_MESSAGEUPDATEBODYRESPONSE']._serialized_start=2455
  _globals['_MESSAGEUPDATEBODYRESPONSE']._serialized_end=2482
  _globals['_MESSAGESENDVOIPREQUEST']._serialized_start=2484
  _globals['_MESSAGESENDVOIPREQUEST']._serialized_end=2545
  _globals['_MESSAGESENDVOIPRESPONSE']._serialized_start=2547
  _globals['_MESSAGESENDVOIPRESPONSE']._serialized_end=2572
# @@protoc_insertion_point(module_scope)
