# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/contact.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'olvid/daemon/datatypes/v1/contact.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import identity_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'olvid/daemon/datatypes/v1/contact.proto\x12\x19olvid.daemon.datatypes.v1\x1a(olvid/daemon/datatypes/v1/identity.proto\"\xe6\x02\n\x07\x43ontact\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12\x44\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.IdentityDetailsR\x07\x64\x65tails\x12:\n\x19\x65stablished_channel_count\x18\x04 \x01(\rR\x17\x65stablishedChannelCount\x12!\n\x0c\x64\x65vice_count\x18\x05 \x01(\rR\x0b\x64\x65viceCount\x12\x38\n\x19has_one_to_one_discussion\x18\x06 \x01(\x08R\x15hasOneToOneDiscussion\x12\x1e\n\x0bhas_a_photo\x18\x07 \x01(\x08R\thasAPhoto\x12)\n\x10keycloak_managed\x18\x08 \x01(\x08R\x0fkeycloakManaged\"\xcc\x05\n\rContactFilter\x12T\n\none_to_one\x18\x01 \x01(\x0e\x32\x31.olvid.daemon.datatypes.v1.ContactFilter.OneToOneH\x00R\x08oneToOne\x88\x01\x01\x12I\n\x05photo\x18\x02 \x01(\x0e\x32..olvid.daemon.datatypes.v1.ContactFilter.PhotoH\x01R\x05photo\x88\x01\x01\x12R\n\x08keycloak\x18\x03 \x01(\x0e\x32\x31.olvid.daemon.datatypes.v1.ContactFilter.KeycloakH\x02R\x08keycloak\x88\x01\x01\x12\x33\n\x13\x64isplay_name_search\x18\x04 \x01(\tH\x03R\x11\x64isplayNameSearch\x88\x01\x01\x12V\n\x0e\x64\x65tails_search\x18\x05 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.IdentityDetailsH\x04R\rdetailsSearch\x88\x01\x01\"P\n\x08OneToOne\x12\x1a\n\x16ONE_TO_ONE_UNSPECIFIED\x10\x00\x12\x11\n\rONE_TO_ONE_IS\x10\x01\x12\x15\n\x11ONE_TO_ONE_IS_NOT\x10\x02\"@\n\x05Photo\x12\x15\n\x11PHOTO_UNSPECIFIED\x10\x00\x12\r\n\tPHOTO_HAS\x10\x01\x12\x11\n\rPHOTO_HAS_NOT\x10\x02\"T\n\x08Keycloak\x12\x18\n\x14KEYCLOAK_UNSPECIFIED\x10\x00\x12\x14\n\x10KEYCLOAK_MANAGED\x10\x01\x12\x18\n\x14KEYCLOAK_NOT_MANAGED\x10\x02\x42\r\n\x0b_one_to_oneB\x08\n\x06_photoB\x0b\n\t_keycloakB\x16\n\x14_display_name_searchB\x11\n\x0f_details_searchB\xc5\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\x0c\x43ontactProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.contact_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\014ContactProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_CONTACT']._serialized_start=113
  _globals['_CONTACT']._serialized_end=471
  _globals['_CONTACTFILTER']._serialized_start=474
  _globals['_CONTACTFILTER']._serialized_end=1190
  _globals['_CONTACTFILTER_ONETOONE']._serialized_start=877
  _globals['_CONTACTFILTER_ONETOONE']._serialized_end=957
  _globals['_CONTACTFILTER_PHOTO']._serialized_start=959
  _globals['_CONTACTFILTER_PHOTO']._serialized_end=1023
  _globals['_CONTACTFILTER_KEYCLOAK']._serialized_start=1025
  _globals['_CONTACTFILTER_KEYCLOAK']._serialized_end=1109
# @@protoc_insertion_point(module_scope)
