# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/command/v1/storage_commands.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'olvid/daemon/command/v1/storage_commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import storage_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_storage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.olvid/daemon/command/v1/storage_commands.proto\x12\x17olvid.daemon.command.v1\x1a\'olvid/daemon/datatypes/v1/storage.proto\"m\n\x12StorageListRequest\x12L\n\x06\x66ilter\x18\x01 \x01(\x0b\x32/.olvid.daemon.datatypes.v1.StorageElementFilterH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"\\\n\x13StorageListResponse\x12\x45\n\x08\x65lements\x18\x01 \x03(\x0b\x32).olvid.daemon.datatypes.v1.StorageElementR\x08\x65lements\"%\n\x11StorageGetRequest\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\"*\n\x12StorageGetResponse\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\";\n\x11StorageSetRequest\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\";\n\x12StorageSetResponse\x12%\n\x0eprevious_value\x18\x01 \x01(\tR\rpreviousValue\"\'\n\x13StorageUnsetRequest\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\"=\n\x14StorageUnsetResponse\x12%\n\x0eprevious_value\x18\x01 \x01(\tR\rpreviousValue\"\x9c\x01\n\x1c\x44iscussionStorageListRequest\x12#\n\rdiscussion_id\x18\x01 \x01(\x04R\x0c\x64iscussionId\x12L\n\x06\x66ilter\x18\x02 \x01(\x0b\x32/.olvid.daemon.datatypes.v1.StorageElementFilterH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"f\n\x1d\x44iscussionStorageListResponse\x12\x45\n\x08\x65lements\x18\x01 \x03(\x0b\x32).olvid.daemon.datatypes.v1.StorageElementR\x08\x65lements\"T\n\x1b\x44iscussionStorageGetRequest\x12#\n\rdiscussion_id\x18\x01 \x01(\x04R\x0c\x64iscussionId\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"4\n\x1c\x44iscussionStorageGetResponse\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\"j\n\x1b\x44iscussionStorageSetRequest\x12#\n\rdiscussion_id\x18\x01 \x01(\x04R\x0c\x64iscussionId\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x14\n\x05value\x18\x03 \x01(\tR\x05value\"E\n\x1c\x44iscussionStorageSetResponse\x12%\n\x0eprevious_value\x18\x01 \x01(\tR\rpreviousValue\"V\n\x1d\x44iscussionStorageUnsetRequest\x12#\n\rdiscussion_id\x18\x01 \x01(\x04R\x0c\x64iscussionId\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"G\n\x1e\x44iscussionStorageUnsetResponse\x12%\n\x0eprevious_value\x18\x01 \x01(\tR\rpreviousValueB\xc3\x01\n\x1b\x63om.olvid.daemon.command.v1B\x14StorageCommandsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODC\xaa\x02\x17Olvid.Daemon.Command.V1\xca\x02\x17Olvid\\Daemon\\Command\\V1\xe2\x02#Olvid\\Daemon\\Command\\V1\\GPBMetadata\xea\x02\x1aOlvid::Daemon::Command::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.command.v1.storage_commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.olvid.daemon.command.v1B\024StorageCommandsProtoP\001Z\017olvid.io/daemon\242\002\003ODC\252\002\027Olvid.Daemon.Command.V1\312\002\027Olvid\\Daemon\\Command\\V1\342\002#Olvid\\Daemon\\Command\\V1\\GPBMetadata\352\002\032Olvid::Daemon::Command::V1'
  _globals['_STORAGELISTREQUEST']._serialized_start=116
  _globals['_STORAGELISTREQUEST']._serialized_end=225
  _globals['_STORAGELISTRESPONSE']._serialized_start=227
  _globals['_STORAGELISTRESPONSE']._serialized_end=319
  _globals['_STORAGEGETREQUEST']._serialized_start=321
  _globals['_STORAGEGETREQUEST']._serialized_end=358
  _globals['_STORAGEGETRESPONSE']._serialized_start=360
  _globals['_STORAGEGETRESPONSE']._serialized_end=402
  _globals['_STORAGESETREQUEST']._serialized_start=404
  _globals['_STORAGESETREQUEST']._serialized_end=463
  _globals['_STORAGESETRESPONSE']._serialized_start=465
  _globals['_STORAGESETRESPONSE']._serialized_end=524
  _globals['_STORAGEUNSETREQUEST']._serialized_start=526
  _globals['_STORAGEUNSETREQUEST']._serialized_end=565
  _globals['_STORAGEUNSETRESPONSE']._serialized_start=567
  _globals['_STORAGEUNSETRESPONSE']._serialized_end=628
  _globals['_DISCUSSIONSTORAGELISTREQUEST']._serialized_start=631
  _globals['_DISCUSSIONSTORAGELISTREQUEST']._serialized_end=787
  _globals['_DISCUSSIONSTORAGELISTRESPONSE']._serialized_start=789
  _globals['_DISCUSSIONSTORAGELISTRESPONSE']._serialized_end=891
  _globals['_DISCUSSIONSTORAGEGETREQUEST']._serialized_start=893
  _globals['_DISCUSSIONSTORAGEGETREQUEST']._serialized_end=977
  _globals['_DISCUSSIONSTORAGEGETRESPONSE']._serialized_start=979
  _globals['_DISCUSSIONSTORAGEGETRESPONSE']._serialized_end=1031
  _globals['_DISCUSSIONSTORAGESETREQUEST']._serialized_start=1033
  _globals['_DISCUSSIONSTORAGESETREQUEST']._serialized_end=1139
  _globals['_DISCUSSIONSTORAGESETRESPONSE']._serialized_start=1141
  _globals['_DISCUSSIONSTORAGESETRESPONSE']._serialized_end=1210
  _globals['_DISCUSSIONSTORAGEUNSETREQUEST']._serialized_start=1212
  _globals['_DISCUSSIONSTORAGEUNSETREQUEST']._serialized_end=1298
  _globals['_DISCUSSIONSTORAGEUNSETRESPONSE']._serialized_start=1300
  _globals['_DISCUSSIONSTORAGEUNSETRESPONSE']._serialized_end=1371
# @@protoc_insertion_point(module_scope)
