# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/group_notifications.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'olvid/daemon/notification/v1/group_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import group_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6olvid/daemon/notification/v1/group_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a%olvid/daemon/datatypes/v1/group.proto\"!\n\x1fSubscribeToGroupNewNotification\"N\n\x14GroupNewNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"%\n#SubscribeToGroupDeletedNotification\"R\n\x18GroupDeletedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\")\n\'SubscribeToGroupNameUpdatedNotification\"{\n\x1cGroupNameUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12#\n\rprevious_name\x18\x02 \x01(\tR\x0cpreviousName\"0\n.SubscribeToGroupDescriptionUpdatedNotification\"\x90\x01\n#GroupDescriptionUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12\x31\n\x14previous_description\x18\x02 \x01(\tR\x13previousDescription\"0\n.SubscribeToGroupPendingMemberAddedNotification\"\xb3\x01\n#GroupPendingMemberAddedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12T\n\x0epending_member\x18\x02 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.PendingGroupMemberR\rpendingMember\"2\n0SubscribeToGroupPendingMemberRemovedNotification\"\xb5\x01\n%GroupPendingMemberRemovedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12T\n\x0epending_member\x18\x02 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.PendingGroupMemberR\rpendingMember\"*\n(SubscribeToGroupMemberJoinedNotification\"\x97\x01\n\x1dGroupMemberJoinedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12>\n\x06member\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x06member\"(\n&SubscribeToGroupMemberLeftNotification\"\x95\x01\n\x1bGroupMemberLeftNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12>\n\x06member\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x06member\"3\n1SubscribeToGroupOwnPermissionsUpdatedNotification\"\x9b\x02\n&GroupOwnPermissionsUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12S\n\x0bpermissions\x18\x02 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x0bpermissions\x12\x64\n\x14previous_permissions\x18\x03 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x13previousPermissions\"6\n4SubscribeToGroupMemberPermissionsUpdatedNotification\"\x89\x02\n)GroupMemberPermissionsUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12>\n\x06member\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x06member\x12\x64\n\x14previous_permissions\x18\x03 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x13previousPermissions\".\n,SubscribeToGroupUpdateInProgressNotification\">\n!GroupUpdateInProgressNotification\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupId\",\n*SubscribeToGroupUpdateFinishedNotification\"<\n\x1fGroupUpdateFinishedNotification\x12\x19\n\x08group_id\x18\x01 \x01(\x04R\x07groupIdB\xdf\x01\n com.olvid.daemon.notification.v1B\x17GroupNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.group_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\027GroupNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOGROUPNEWNOTIFICATION']._serialized_start=127
  _globals['_SUBSCRIBETOGROUPNEWNOTIFICATION']._serialized_end=160
  _globals['_GROUPNEWNOTIFICATION']._serialized_start=162
  _globals['_GROUPNEWNOTIFICATION']._serialized_end=240
  _globals['_SUBSCRIBETOGROUPDELETEDNOTIFICATION']._serialized_start=242
  _globals['_SUBSCRIBETOGROUPDELETEDNOTIFICATION']._serialized_end=279
  _globals['_GROUPDELETEDNOTIFICATION']._serialized_start=281
  _globals['_GROUPDELETEDNOTIFICATION']._serialized_end=363
  _globals['_SUBSCRIBETOGROUPNAMEUPDATEDNOTIFICATION']._serialized_start=365
  _globals['_SUBSCRIBETOGROUPNAMEUPDATEDNOTIFICATION']._serialized_end=406
  _globals['_GROUPNAMEUPDATEDNOTIFICATION']._serialized_start=408
  _globals['_GROUPNAMEUPDATEDNOTIFICATION']._serialized_end=531
  _globals['_SUBSCRIBETOGROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_start=533
  _globals['_SUBSCRIBETOGROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_end=581
  _globals['_GROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_start=584
  _globals['_GROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_end=728
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_start=730
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_end=778
  _globals['_GROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_start=781
  _globals['_GROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_end=960
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_start=962
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_end=1012
  _globals['_GROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_start=1015
  _globals['_GROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_end=1196
  _globals['_SUBSCRIBETOGROUPMEMBERJOINEDNOTIFICATION']._serialized_start=1198
  _globals['_SUBSCRIBETOGROUPMEMBERJOINEDNOTIFICATION']._serialized_end=1240
  _globals['_GROUPMEMBERJOINEDNOTIFICATION']._serialized_start=1243
  _globals['_GROUPMEMBERJOINEDNOTIFICATION']._serialized_end=1394
  _globals['_SUBSCRIBETOGROUPMEMBERLEFTNOTIFICATION']._serialized_start=1396
  _globals['_SUBSCRIBETOGROUPMEMBERLEFTNOTIFICATION']._serialized_end=1436
  _globals['_GROUPMEMBERLEFTNOTIFICATION']._serialized_start=1439
  _globals['_GROUPMEMBERLEFTNOTIFICATION']._serialized_end=1588
  _globals['_SUBSCRIBETOGROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=1590
  _globals['_SUBSCRIBETOGROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=1641
  _globals['_GROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=1644
  _globals['_GROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=1927
  _globals['_SUBSCRIBETOGROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=1929
  _globals['_SUBSCRIBETOGROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=1983
  _globals['_GROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=1986
  _globals['_GROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=2251
  _globals['_SUBSCRIBETOGROUPUPDATEINPROGRESSNOTIFICATION']._serialized_start=2253
  _globals['_SUBSCRIBETOGROUPUPDATEINPROGRESSNOTIFICATION']._serialized_end=2299
  _globals['_GROUPUPDATEINPROGRESSNOTIFICATION']._serialized_start=2301
  _globals['_GROUPUPDATEINPROGRESSNOTIFICATION']._serialized_end=2363
  _globals['_SUBSCRIBETOGROUPUPDATEFINISHEDNOTIFICATION']._serialized_start=2365
  _globals['_SUBSCRIBETOGROUPUPDATEFINISHEDNOTIFICATION']._serialized_end=2409
  _globals['_GROUPUPDATEFINISHEDNOTIFICATION']._serialized_start=2411
  _globals['_GROUPUPDATEFINISHEDNOTIFICATION']._serialized_end=2471
# @@protoc_insertion_point(module_scope)
