# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/client_key.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'olvid/daemon/datatypes/v1/client_key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*olvid/daemon/datatypes/v1/client_key.proto\x12\x19olvid.daemon.datatypes.v1\"R\n\tClientKey\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x1f\n\x0bidentity_id\x18\x03 \x01(\x04R\nidentityId\"\xb4\x01\n\x0f\x43lientKeyFilter\x12\x1d\n\tadmin_key\x18\x01 \x01(\x08H\x00R\x08\x61\x64minKey\x12!\n\x0bidentity_id\x18\x02 \x01(\x04H\x00R\nidentityId\x12$\n\x0bname_search\x18\x03 \x01(\tH\x01R\nnameSearch\x88\x01\x01\x12\x15\n\x03key\x18\x04 \x01(\tH\x02R\x03key\x88\x01\x01\x42\n\n\x08identityB\x0e\n\x0c_name_searchB\x06\n\x04_keyB\xc7\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\x0e\x43lientKeyProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.client_key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\016ClientKeyProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_CLIENTKEY']._serialized_start=73
  _globals['_CLIENTKEY']._serialized_end=155
  _globals['_CLIENTKEYFILTER']._serialized_start=158
  _globals['_CLIENTKEYFILTER']._serialized_end=338
# @@protoc_insertion_point(module_scope)
